@@ -41,17 +41,19 @@ int UTF8Encode2BytesUnicode( unsigned short input, char * s )
 		return 2;
 	}
 	// 1110xxxx 10xxxxxx 10xxxxxx
-	else if( input < 0x10000 )
+	else // if( input < 0x10000 ) // the input is unsigned short, so tautology
 	{
 		s[ 0 ] = (MASK3BYTES | ( input >> 12 ) );
 		s[ 1 ] = (MASKBYTE | ( ( input >> 6 ) & MASKBITS ) );
 		s[ 2 ] = (MASKBYTE | ( input & MASKBITS ) );
 		return 3;
 	}
+	return 0; // avoid compiler warnings
 }
 
 
-#define ASSERT(cond)  if(!(cond))  error("overrunning buffers in mapString");
+#define ASSERT(cond)  if(!(cond)) error("overrunning buffers in mapString"); 
+
 
 /* Convert a string with \unnnn elements to its Unicode form.
   s - the input string
